adapters
library
Classes
BinaryReader
The BinaryReader is used to bring data back from the binary format on the
disk.
BinaryWriter
The BinaryWriter is used to encode data to the binary format.
Box <E >
Boxes contain all of your data. In the browser, each box has its own
IndexedDB database. On all other platforms, each Box is stored in a
separate file in the Hive home directory.
BoxBase <E >
Boxes contain all of your data. In the browser, each box has its own
IndexedDB database. On all other platforms, each Box is stored in a
seperate file in the Hive home directory.
BoxEvent
A event representing a change in a box.
ColorAdapter
HiveAesCipher
Default encryption algorithm. Uses AES256 CBC with PKCS7 padding.
HiveCipher
Abstract cipher can be implemented to customize encryption.
HiveField
Annotate all fields you want to persist with HiveField .
HiveInterface
The main API interface of Hive. Available through the Hive constant.
HiveObject
HiveType
Annotate classes with HiveType to generate a TypeAdapter.
LazyBox <E >
LazyBox es don't keep the values in memory like normal boxes. Each time a
value is read, it is loaded from the backend.
TimeOfDayAdapter
TypeAdapter <T >
Type adapters can be implemented to support non primitive values.
TypeRegistry
TypeRegistries contain the TypeAdapter s associated with a typeId.
Mixins
HiveObjectMixin
Extend HiveObject to add useful methods to the objects you want to store
in Hive
Exceptions / Errors
HiveError
An error related to Hive.