BinaryReader class abstract

The BinaryReader is used to bring data back from the binary format on the disk.

Constructors

BinaryReader()

Properties

availableBytes → int
The number of bytes left in this entry.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usedBytes → int
The number of read bytes.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peekBytes(int bytes) → Uint8List
Get a Uint8List view which contains the next bytes bytes. This does not advance the internal read position.
read([int? typeId]) → dynamic
Read and decode any value.
readBool() → bool
Read a boolean.
readBoolList([int? length]) → List<bool>
Read a list of booleans with length.
readByte() → int
Read a single byte.
readByteList([int? length]) → Uint8List
Read a list of bytes with length.
readDouble() → double
Read eight bytes as 64-bit double.
readDoubleList([int? length]) → List<double>
Read a list of doubles with length.
readInt() → int
Read eight bytes as 64-bit signed integer.
readInt32() → int
Read four bytes as 32-bit signed integer.
readIntList([int? length]) → List<int>
Read a list of integers with length.
readList([int? length]) → List
Read a list with length.
readMap([int? length]) → Map
Read a map with length entries.
readString([int? byteCount, Converter<List<int>, String> decoder = utf8Decoder]) → String
Read byteCount bytes and decode an UTF-8 String.
readStringList([int? length, Converter<List<int>, String> decoder = utf8Decoder]) → List<String>
Read a list of Strings with length.
readUint32() → int
Read four bytes as 32-bit unsigned integer.
readWord() → int
Read two bytes as 16-bit unsigned integer.
skip(int bytes) → void
Skip n bytes.
toString() → String
A string representation of this object.
inherited
viewBytes(int bytes) → Uint8List
Get a Uint8List view which contains the next bytes bytes.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

utf8Decoder → const Utf8Decoder
The UTF-8 decoder is used to decode Strings.